@@ -1,4 +1,5 @@
 import json
+import pkgutil
 import mpu
 
 from deutsche_bahn_api.station import Station
@@ -21,10 +22,10 @@ class StationHelper:
         self.stations_list = []
 
     def load_stations(self):
-        with open('static/train_stations_list.json') as stationsFile:
-            stations = json.load(stationsFile)
-            for item in stations:
-                self.stations_list.append(Station(**item))
+        json_raw = pkgutil.get_data(__name__, "static/train_stations_list.json")
+        stations = json.loads(json_raw)
+        for item in stations:
+            self.stations_list.append(Station(**item))
 
     def find_stations_by_lat_long(self, target_lat: float, target_long: float, radius: int) -> list[Station]:
         results: list[Station] = []
